==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/language/1/barnraiser_01/my_publishing.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');


//SECTION
$lang['section_publish_community'] = 			"community contributions";
$lang['section_publish_group'] = 				"group contributions";


//HEADER
$lang['hdr_publish_blog_item'] = 				"published journals";
$lang['hdr_publish_forum'] =		 			"published discussion posts";
$lang['hdr_poll_participation'] = 				"poll participation";
$lang['hdr_publish_library'] = 					"published library documents";
$lang['hdr_publish_shouts'] = 					"published shouts";


//ERRORS
$lang['err_no_blogs'] = 						"Sorry, you have no blog contents.";
$lang['err_no_library'] = 						"Sorry, you have no library documents.";
$lang['err_no_poll_participation'] =			"Sorry, you have not voted.";
$lang['err_no_shouts'] = 						"Sorry, no shouts.";
$lang['err_no_forum'] = 						"Sorry, you have no discussion posts.";


//BODY
$lang['txt_publishing'] = 						"publishing";//breadcrumb

?>

==> aroundme_0_6_0.zip: aroundme_0_6_0/aroundme/language/1/barnraiser_01/my_publishing.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');


//SECTION
$lang['hdr_publish_community'] = 			"your contributions";


//HEADER
$lang['hdr_publish_blog_item'] = 				"published blogs";
$lang['hdr_publish_forum'] =		 			"published discussions";
$lang['hdr_poll_participation'] = 				"poll participation";
$lang['hdr_publish_library'] = 					"published wiki pages";
$lang['hdr_publish_shouts'] = 					"published shouts";


//ERRORS
$lang['err_no_blogs'] = 						"Sorry, you have no blog contents.";
$lang['err_no_library'] = 						"Sorry, you have no wiki pages.";
$lang['err_no_poll_participation'] =			"Sorry, you have not voted.";
$lang['err_no_shouts'] = 						"Sorry, no shouts.";
$lang['err_no_forum'] = 						"Sorry, you have no discussions.";


//BODY
$lang['txt_publishing'] = 						"publishing";//breadcrumb

?>
